pyLBM.elements.Parallelepiped
=============================

.. currentmodule:: pyLBM.elements

.. autoclass:: Parallelepiped

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Parallelepiped.change_of_variables
         Parallelepiped.distance
         Parallelepiped.get_bounds
         Parallelepiped.point_inside
         Parallelepiped.test_label



   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Parallelepiped.number_of_bounds

